#
# spec file for package pipewire
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2018 Luciano Santos, luc14n0@linuxmail.org.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _use_internal_dependency_generator 0

%global provfind sh -c "grep -v -e 'libpulse.*\\.so' -e 'libjack.*\\.so' | %__find_provides"
%global __find_provides %provfind

# Note: Replace the Requires: pipewire with a Recommends below in libpipewire
#       with the next apiver change
%define sover 0_3_6
%define apiver 0.3
%define apiver_str 0_3
%define spa_ver 0.2
%define spa_ver_str 0_2

%define libpipewire libpipewire-%{apiver_str}-0
%if %{pkg_vcmp pkgconfig(vulkan) >= 1.1}
%define with_vulkan 1
%else
%define with_vulkan 0
%endif

Name:           pipewire
Version:        0.3.6
Release:        lp152.2.3.1
Summary:        A Multimedia Framework designed to be an audio and video server and more
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://pipewire.org/
Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}-rpmlintrc
Patch0:         fix-memfd_create-call.patch
Patch1:         do-not-use-snd_pcm_ioplug_hw_avail.patch
Patch2:         fix-meson-required-version.patch
Patch101:       0001-client-node-fix-buffer-size-calculation.patch
Patch102:       0002-gst-fix-proxy-leaks.patch
Patch103:       0003-pulse-fix-pa_card_info-profiles2-array-to-be-NULL-terminated.patch
Patch104:       0004-pulse-fix-size-calculation.patch
Patch105:       0005-jack-fix-crash-on-close-when-metadata-are-not-available.patch
Patch106:       0006-a2dpsink-only-request-new-data-when-buffer-is-done.patch
Patch107:       0007-pulse-fix-counter-while-populating-car_info-profiles.patch
Patch108:       0008-impl-link-reset-state-before-starting-allocation.patch
Patch109:       0009-impl-core-clear-the-mempool.patch
Patch110:       0010-mem-reset-the-map-in-clear.patch
Patch111:       0011-avoid-uninitialized-variables.patch
Patch112:       0012-dlclose-on-errors.patch
Patch113:       0013-stream-handle-NULL-context.patch
Patch114:       0014-state-always-update-state-variables.patch
Patch115:       0015-spa-device-fix-leak-of-properties-in-error-case.patch
Patch116:       0016-alsa-dont-leak-structure-on-error.patch
Patch117:       0017-alsa-dont-leak-properties-on-error.patch
Patch118:       0018-stream-fix-some-more-leaks-in-error-paths.patch
Patch119:       0019-buffers-increase-max-datas-and-metadata-in-buffers.patch
Patch120:       0020-gst-return-NULL-for-unknown-format.patch

BuildRequires:  doxygen
BuildRequires:  fdupes
%if 0%{?suse_version} <= 1500
BuildRequires:  gcc9
%endif
BuildRequires:  graphviz
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  xmltoman
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(bluez)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.32.0
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-allocators-1.0)
BuildRequires:  pkgconfig(gstreamer-audio-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(gstreamer-video-1.0)
BuildRequires:  pkgconfig(jack) >= 1.9.10
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavfilter)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(sbc)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(vulkan)
BuildRequires:  pkgconfig(x11)
Requires:       %{libpipewire} = %{version}
Requires:       %{name}-modules = %{version}
Requires:       %{name}-spa-plugins-%{spa_ver_str} = %{version}
Requires:       %{name}-spa-tools = %{version}
Requires:       %{name}-tools = %{version}

%description
PipeWire is a server and user space API to deal with multimedia pipelines.

Some of its features include:

 * Capture and playback of audio and video with minimal latency;
 * Real-time Multimedia processing on audio and video;
 * Multiprocess architecture to let applications share multimedia content;
 * GStreamer plugins for easy use and integration in current applications;
 * Sandboxed applications support.

%package -n %{libpipewire}
Summary:        A Multimedia Framework designed to be an audio and video server and more
License:        MIT
Group:          System/Libraries
# TODO: Replace the Requires: pipewire with a Recommends with the next apiver bump
Requires:       pipewire

%description -n %{libpipewire}
PipeWire is a server and user space API to deal with multimedia pipelines.

Some of its features include:

 * Capture and playback of audio and video with minimal latency;
 * Real-time Multimedia processing on audio and video;
 * Multiprocess architecture to let applications share multimedia content;
 * GStreamer plugins for easy use and integration in current applications;
 * Sandboxed applications support.

This package provides the PipeWire shared library.

%package libjack-%{apiver_str}
Summary:        PipeWire libjack replacement libraries
License:        MIT
Group:          Development/Libraries/C and C++
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description libjack-%{apiver_str}
PipeWire is a server and user space API to deal with multimedia pipelines.

Some of its features include:

 * Capture and playback of audio and video with minimal latency;
 * Real-time Multimedia processing on audio and video;
 * Multiprocess architecture to let applications share multimedia content;
 * GStreamer plugins for easy use and integration in current applications;
 * Sandboxed applications support.

This package provides the PipeWire replacement libraries for libjack.


%package libpulse-%{apiver_str}
Summary:        A Multimedia Framework designed to be an audio and video server and more
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description libpulse-%{apiver_str}
PipeWire is a server and user space API to deal with multimedia pipelines.

Some of its features include:

 * Capture and playback of audio and video with minimal latency;
 * Real-time Multimedia processing on audio and video;
 * Multiprocess architecture to let applications share multimedia content;
 * GStreamer plugins for easy use and integration in current applications;
 * Sandboxed applications support.

This package provides the PipeWire shared library.

%package -n gstreamer-plugin-pipewire
Summary:        Gstreamer Plugin for PipeWire
License:        MIT
Group:          System/Libraries

%description -n gstreamer-plugin-pipewire
PipeWire is a server and user space API to deal with multimedia pipelines.

This package provides the gstreamer plugin.

%package tools
Summary:        The PipeWire Tools
License:        MIT
Group:          Productivity/Multimedia/Other

%description tools
SPA or Simple Plugin API is a plugin API.

This package provides pipewire-cli and pipewire-monitor tools.

%package spa-tools
Summary:        The PipeWire SPA Tools
License:        MIT
Group:          Productivity/Multimedia/Other

%description spa-tools
SPA or Simple Plugin API is a plugin API.

This package provides spa-inspect and spa-monitor tools.

%package modules
Summary:        Modules For PipeWire, A Multimedia Framework
License:        MIT
Group:          Productivity/Multimedia/Other
Requires:       pipewire

%description modules
PipeWire is a server and user space API to deal with multimedia pipelines.

The framework is used to build a modular daemon that can be configured to:

 * Be a low-latency audio server with features like pulseaudio and/or jack;
 * A video capture server that can manage hardware video capture devices
   and provide access to them;
 * A central hub where video can be made available for other applications
   such as the gnome-shell screencast API.

%package spa-plugins-%{spa_ver_str}
Summary:        Plugins For PipeWire SPA
License:        MIT
Group:          Productivity/Multimedia/Other
Requires:       pipewire

%description spa-plugins-%{spa_ver_str}
PipeWire is a server and user space API to deal with multimedia pipelines.

Some of its features include:

 * Unlimited input/output ports;
 * Per port format enumeration and negotiation;
 * Enumeration/configuration of per port parameters;
 * Application controlled buffer allocation with option to let the plugin
   Allocate memory;
 * Arbitrary buffer metadata;
 * Buffers are passed around by id which is very fast and avoids the need
   for refcounting;
 * Synchronous and asynchronous processing;
 * All api is designed to work without any allocations;
 * Arbirary input/output behaviour.

This package provides plugins for extending PipeWire SPA's functionality.

%package devel
Summary:        Development Files For PipeWire, A Multimedia Framework
License:        MIT
Group:          Development/Libraries/C and C++
Requires:       %{libpipewire} >= %{version}

%description devel
PipeWire is a server and user space API to deal with multimedia pipelines.

This package provides all the necessary files for development with PipeWire

%package doc
Summary:        PipeWire media server documentation
License:        MIT
Group:          Development/Libraries/C and C++

%description doc
This package contains documentation for the PipeWire media server.

%prep
%setup
%if %{pkg_vcmp glibc < 2.27}
%patch0 -p1
%endif

%if %{pkg_vcmp alsa-devel < 1.1.7}
%patch1 -p1
sed -i -e "s/dependency('alsa', version : '>=1.1.7')/dependency('alsa', version : '>=1.1.5')/" meson.build
%endif
%patch2 -p1

%patch101 -p1
%patch102 -p1
%patch103 -p1
%patch104 -p1
%patch105 -p1
%patch106 -p1
%patch107 -p1
%patch108 -p1
%patch109 -p1
%patch110 -p1
%patch111 -p1
%patch112 -p1
%patch113 -p1
%patch114 -p1
%patch115 -p1
%patch116 -p1
%patch117 -p1
%patch118 -p1
%patch119 -p1
%patch120 -p1

%build
%if %{pkg_vcmp gcc < 8}
export CC=gcc-9
%endif
%meson \
	-Ddocs=true \
	-Dman=true \
	-Dgstreamer=true \
	-Dffmpeg=true \
	-Dsystemd=true \
%if %{with_vulkan}
	-Dvulkan=true \
%else
	-Dvulkan=false \
%endif
	-Dtest=true \
	-Daudiotestsrc=true \
	%{nil}
%meson_build

%install
%meson_install

mkdir -p %{buildroot}%{_sysconfdir}/alsa/conf.d/
for filename in 50-pipewire.conf \
                99-pipewire-default.conf ; do
    cp -a pipewire-alsa/conf/"$filename" %{buildroot}%{_sysconfdir}/alsa/conf.d/
done

mkdir -p %{buildroot}%{_sysconfdir}/alternatives
for wrapper in pw-pulse pw-jack ; do
    mv  %{buildroot}%{_bindir}/$wrapper   %{buildroot}%{_bindir}/$wrapper-%{apiver}
    ln -s -f %{_sysconfdir}/alternatives/$wrapper %{buildroot}%{_bindir}/$wrapper
done

for manpage in pw-jack pw-pulse ; do
    mv  %{buildroot}%{_mandir}/man1/$manpage.1 %{buildroot}%{_mandir}/man1/$manpage-%{apiver}.1
    ln -s -f %{_sysconfdir}/alternatives/$manpage.1%{ext_man} %{buildroot}%{_mandir}/man1/$manpage.1%{ext_man}
done

%fdupes -s %{buildroot}/%{_datadir}/doc/pipewire/html

%check
%meson_test

%post
if [ ! -f /etc/systemd/user/sockets.target.wants/%{name}.socket ]; then
  echo "Switching Pipewire activation using systemd user socket."
  echo "Please log out from all sessions once to make it effective."
fi
%systemd_user_post pipewire.socket
# FIXME: workaround to make sure the user socket symlink creation (related to bsc#1083473)
if [ ! -f /etc/systemd/user/sockets.target.wants/%{name}.socket ]; then
  # below should work once when preset is defined properly:
  #  /usr/bin/systemctl --no-reload --global preset pipewire.socket
  mkdir -p /etc/systemd/user/sockets.target.wants
  ln -s %{_userunitdir}/%{name}.socket /etc/systemd/user/sockets.target.wants/%{name}.socket
fi

%preun
%systemd_user_preun pipewire.socket

%postun
%systemd_user_postun pipewire.socket

%post   -n %{libpipewire} -p /sbin/ldconfig
%postun -n %{libpipewire} -p /sbin/ldconfig

%post libpulse-%{apiver_str}
%{_sbindir}/update-alternatives --install %{_bindir}/pw-pulse pw-pulse %{_bindir}/pw-pulse-%{apiver} 20 \
    --slave %{_mandir}/man1/pw-pulse.1%{ext_man} pw-pulse.1%{ext_man} %{_mandir}/man1/pw-pulse-%{apiver}.1%{ext_man}

%postun libpulse-%{apiver_str}
if [ ! -e %{_bindir}/pw-pulse-%{apiver} ] ; then
  %{_sbindir}/update-alternatives --remove pw-pulse %{_bindir}/pw-pulse-%{apiver}
fi

%post libjack-%{apiver_str}
%{_sbindir}/update-alternatives --install %{_bindir}/pw-jack pw-jack %{_bindir}/pw-jack-%{apiver} 20 \
    --slave %{_mandir}/man1/pw-jack.1%{ext_man} pw-jack.1%{ext_man} %{_mandir}/man1/pw-jack-%{apiver}.1%{ext_man}

%postun libjack-%{apiver_str}
if [ ! -e %{_bindir}/pw-jack-%{apiver} ] ; then
  %{_sbindir}/update-alternatives --remove pw-jack %{_bindir}/pw-jack-%{apiver}
fi

%files
%{_bindir}/pipewire
%{_bindir}/pipewire-media-session
%{_userunitdir}/pipewire.service
%{_userunitdir}/pipewire.socket
%{_mandir}/man1/pipewire.1%{ext_man}
%{_mandir}/man5/pipewire.conf.5%{ext_man}

%dir %{_sysconfdir}/pipewire
%config %{_sysconfdir}/pipewire/pipewire.conf

%dir %{_libdir}/alsa-lib
%{_libdir}/alsa-lib/libasound_module_pcm_pipewire.so
%dir %{_datadir}/alsa/alsa.conf.d
%{_datadir}/alsa/alsa.conf.d/50-pipewire.conf
%{_datadir}/alsa/alsa.conf.d/99-pipewire-default.conf
%dir %{_sysconfdir}/alsa
%dir %{_sysconfdir}/alsa/conf.d
%config(noreplace) %{_sysconfdir}/alsa/conf.d/50-pipewire.conf
%config(noreplace) %{_sysconfdir}/alsa/conf.d/99-pipewire-default.conf

%files -n %{libpipewire}
%license LICENSE COPYING
%doc README.md
%{_libdir}/libpipewire-%{apiver}.so.*

%files libjack-%{apiver_str}
%dir %{_libdir}/pipewire-%{apiver}/jack
%{_libdir}/pipewire-%{apiver}/jack/libjack.so*
%{_libdir}/pipewire-%{apiver}/jack/libjacknet.so*
%{_libdir}/pipewire-%{apiver}/jack/libjackserver.so*
%ghost %{_sysconfdir}/alternatives/pw-jack
%ghost %{_sysconfdir}/alternatives/pw-jack.1%{ext_man}
%{_bindir}/pw-jack-%{apiver}
%{_bindir}/pw-jack
%{_mandir}/man1/pw-jack-%{apiver}.1%{ext_man}
%{_mandir}/man1/pw-jack.1%{ext_man}

%files libpulse-%{apiver_str}
%license pipewire-pulseaudio/LICENSE
%dir %{_libdir}/pipewire-%{apiver}/pulse
%{_libdir}/pipewire-%{apiver}/pulse/libpulse.so*
%{_libdir}/pipewire-%{apiver}/pulse/libpulse-simple.so*
%{_libdir}/pipewire-%{apiver}/pulse/libpulse-mainloop-glib.so*
%ghost %{_sysconfdir}/alternatives/pw-pulse
%ghost %{_sysconfdir}/alternatives/pw-pulse.1%{ext_man}
%{_bindir}/pw-pulse-%{apiver}
%{_bindir}/pw-pulse
%{_mandir}/man1/pw-pulse-%{apiver}.1%{ext_man}
%{_mandir}/man1/pw-pulse.1%{ext_man}

%files -n gstreamer-plugin-pipewire
%{_libdir}/gstreamer-1.0/libgstpipewire.so

%files tools
%{_bindir}/pw-cli
%{_bindir}/pw-dot
%{_bindir}/pw-mon
%{_bindir}/pw-profiler
%{_bindir}/pw-cat
%{_bindir}/pw-play
%{_bindir}/pw-record
%{_bindir}/pw-metadata
%{_bindir}/pw-mididump
%{_bindir}/pw-midiplay
%{_bindir}/pw-midirecord
%{_mandir}/man1/pw-cli.1%{ext_man}
%{_mandir}/man1/pw-mon.1%{ext_man}
%{_mandir}/man1/pw-cat.1%{ext_man}
%{_mandir}/man1/pw-dot.1%{ext_man}
%{_mandir}/man1/pw-metadata.1%{ext_man}
%{_mandir}/man1/pw-mididump.1%{ext_man}
%{_mandir}/man1/pw-profiler.1%{ext_man}

%files spa-tools
%{_bindir}/spa-inspect
%{_bindir}/spa-monitor

%files modules
%dir %{_libdir}/pipewire-%{apiver}
%{_libdir}/pipewire-%{apiver}/libpipewire-module-access.so
%{_libdir}/pipewire-%{apiver}/libpipewire-module-adapter.so
%{_libdir}/pipewire-%{apiver}/libpipewire-module-client-device.so
%{_libdir}/pipewire-%{apiver}/libpipewire-module-client-node.so
%{_libdir}/pipewire-%{apiver}/libpipewire-module-link-factory.so
%{_libdir}/pipewire-%{apiver}/libpipewire-module-metadata.so
%{_libdir}/pipewire-%{apiver}/libpipewire-module-portal.so
%{_libdir}/pipewire-%{apiver}/libpipewire-module-profiler.so
%{_libdir}/pipewire-%{apiver}/libpipewire-module-protocol-native.so
%{_libdir}/pipewire-%{apiver}/libpipewire-module-rtkit.so
%{_libdir}/pipewire-%{apiver}/libpipewire-module-session-manager.so
%{_libdir}/pipewire-%{apiver}/libpipewire-module-spa-device-factory.so
%{_libdir}/pipewire-%{apiver}/libpipewire-module-spa-device.so
%{_libdir}/pipewire-%{apiver}/libpipewire-module-spa-node-factory.so
%{_libdir}/pipewire-%{apiver}/libpipewire-module-spa-node.so

%files spa-plugins-%{spa_ver_str}
%{_libdir}/spa-%{spa_ver}/alsa/libspa-alsa.so
%{_libdir}/spa-%{spa_ver}/audioconvert/libspa-audioconvert.so
%{_libdir}/spa-%{spa_ver}/audiomixer/libspa-audiomixer.so
%{_libdir}/spa-%{spa_ver}/bluez5/libspa-bluez5.so
%{_libdir}/spa-%{spa_ver}/control/libspa-control.so
%{_libdir}/spa-%{spa_ver}/ffmpeg/libspa-ffmpeg.so
%{_libdir}/spa-%{spa_ver}/jack/libspa-jack.so
%{_libdir}/spa-%{spa_ver}/support/libspa-dbus.so
%{_libdir}/spa-%{spa_ver}/support/libspa-support.so
%{_libdir}/spa-%{spa_ver}/v4l2/libspa-v4l2.so
%{_libdir}/spa-%{spa_ver}/videoconvert/libspa-videoconvert.so
%if %{with_vulkan}
%{_libdir}/spa-%{spa_ver}/vulkan/libspa-vulkan.so
%endif
%{_libdir}/spa-%{spa_ver}/audiotestsrc/libspa-audiotestsrc.so
%{_libdir}/spa-%{spa_ver}/test/libspa-test.so

%dir %{_libdir}/spa-%{spa_ver}
%dir %{_libdir}/spa-%{spa_ver}/alsa
%dir %{_libdir}/spa-%{spa_ver}/audioconvert
%dir %{_libdir}/spa-%{spa_ver}/audiomixer
%dir %{_libdir}/spa-%{spa_ver}/bluez5
%dir %{_libdir}/spa-%{spa_ver}/control
%dir %{_libdir}/spa-%{spa_ver}/ffmpeg
%dir %{_libdir}/spa-%{spa_ver}/jack
%dir %{_libdir}/spa-%{spa_ver}/support
%dir %{_libdir}/spa-%{spa_ver}/v4l2
%dir %{_libdir}/spa-%{spa_ver}/videoconvert
%if %{with_vulkan}
%dir %{_libdir}/spa-%{spa_ver}/vulkan
%endif
%dir %{_libdir}/spa-%{spa_ver}/audiotestsrc
%dir %{_libdir}/spa-%{spa_ver}/test

%files devel
%{_libdir}/libpipewire-%{apiver}.so
%{_libdir}/pkgconfig/libpipewire-%{apiver}.pc
%{_libdir}/pkgconfig/libspa-%{spa_ver}.pc
%{_includedir}/pipewire-%{apiver}/
%{_includedir}/spa-%{spa_ver}/

%files doc
%dir %{_datadir}/doc/pipewire
%{_datadir}/doc/pipewire/html

%changelog
* Wed Jul 15 2020 Antonio Larrosa <alarrosa@suse.com>
- Require pipewire from libpipewire (instead of Recommending it)
  in SLE/Leap, so a zypper update of the system pulls in the
  pipewire daemon. Add a note to change it back to a
  recommendation when the api version changes which would make
  recommendations get reevaluated by zypper (jsc#ECO-2308)
* Wed Jul 15 2020 Antonio Larrosa <alarrosa@suse.com>
- Recommend pipewire from libpipewire, so if the library is
  installed the daemon gets pulled in since we want a daemon
  to connect to.
- Require pipewire-spa-plugins from pipewire instead of
  recommending it since the support plugin is actually required
  for most uses (like screen sharing in wayland, which we want to
  support out-of-the-box).
- Enable the pipewire.socket systemd user service in %%post
  (using pulseaudio's %%post section as an example of how to do it
  since systemd-presets-common-SUSE currently lacks support for
  user services). Also disable it in %%preun and %%postun.
* Tue Jul 14 2020 Antonio Larrosa <alarrosa@suse.com>
- Add patches from upstream to fix many issues mainly related to
  memory leaks, crashes and wrong behaviour:
  * 0001-client-node-fix-buffer-size-calculation.patch
  * 0002-gst-fix-proxy-leaks.patch
  * 0003-pulse-fix-pa_card_info-profiles2-array-to-be-NULL-terminated.patch
  * 0004-pulse-fix-size-calculation.patch
  * 0005-jack-fix-crash-on-close-when-metadata-are-not-available.patch
  * 0006-a2dpsink-only-request-new-data-when-buffer-is-done.patch
  * 0007-pulse-fix-counter-while-populating-car_info-profiles.patch
  * 0008-impl-link-reset-state-before-starting-allocation.patch
  * 0009-impl-core-clear-the-mempool.patch
  * 0010-mem-reset-the-map-in-clear.patch
  * 0011-avoid-uninitialized-variables.patch
  * 0012-dlclose-on-errors.patch
  * 0013-stream-handle-NULL-context.patch
  * 0014-state-always-update-state-variables.patch
  * 0015-spa-device-fix-leak-of-properties-in-error-case.patch
  * 0016-alsa-dont-leak-structure-on-error.patch
  * 0017-alsa-dont-leak-properties-on-error.patch
  * 0018-stream-fix-some-more-leaks-in-error-paths.patch
  * 0019-buffers-increase-max-datas-and-metadata-in-buffers.patch
  * 0020-gst-return-NULL-for-unknown-format.patch
* Fri Jul  3 2020 Antonio Larrosa <alarrosa@suse.com>
- Rebase patches used in SLE/Leap:
  * do-not-use-snd_pcm_ioplug_hw_avail.patch
  * fix-memfd_create-call.patch
* Tue Jun 16 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to version 0.3.6 (boo#1171433, jsc#ECO-2308):
  * Extensive memory leak fixing and stress testing was done.
    A big leak in screen sharing with DMA-BUF was fixed.
  * Compile fixes
  * Stability improvements in jack and pulseaudio layers.
  * Added the old portal module to make the Camera portal
    work again. This will be moved to the session manager in
    future versions.
  * Improvements to the GStreamer source and sink shutdown.
  * Fix compatibility with v2 clients again when negotiating
    buffers.
- Disable vulkan if the vulkan package is too old (as in
  SLE 15 SP0 and SP1)
- Add patch to build with meson >= 0.46.0 since 0.50.0 is not
  really needed:
  * fix-meson-required-version.patch
* Thu May 21 2020 Antonio Larrosa <alarrosa@suse.com>
- Filter out libpulse.so.0 and libjack.so.0 automatic provides so
  this is not considered an alternative when resolving dependencies
  in the distribution.
* Thu May 21 2020 Antonio Larrosa <alarrosa@suse.com>
- Add patch to fix build in SLE/Leap where alsa doesn't have a
  snd_pcm_ioplug_hw_avail function:
  * do-not-use-snd_pcm_ioplug_hw_avail.patch
* Tue May 19 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to version 0.3.5:
  * Compiler fixes
  * Add pw-midiplay and pw-midirecord aliases
  * Add pw-mididump tool
  * Add pw-metadata tool to inspect, add and remove metadata
    for objects.
  * Docs updates, man pages
  * install alsa config files
  * Fix linked sink/source in pulseaudio
  * ratelimit graph processing warnings
  * improve buffer handling in GStreamer elements
  * Fix power usage by removing the queue for the alsa
    sequencer system announce messages.
  * Fix metadata clear() method dispatch.
  * Improve parameter enumeration, make it possible to detect
    missing parameters vs no-compatible parameters so that we
    can use defaults in the first case and error in the second
    case.
  * Fix cleanup of proxy objects. Stability improvements on
    plug/unplug in session manager.
  * Make it possible to set log level from config file
  * improve debug of param negotiation errors. Log the
    parameters to stderr/journal.
  * Make it possible to configure global logger
    implementation.
  * Fix NEON detection
  * JACK and PulseAudio compatibility improvements
- Update to version 0.3.4:
  * A quick update with some important stability fixes.
- Update to version 0.3.3:
  * NEON optimizations for audio conversion (32 and 64 bits)
  * rework of session manager implementation
  * Add option to disable modules in the session manager
  * Release midi hardware devices when suspended
  * various build fixes
  * Clean up options of various utils
  * Stability improvements
  * Mayor improvements in pulseaudio emulation. Improved
    timings and compatibility.
  * Implementation of drain and flush in pulse and alsa
    emulation.
  * Implement poll on file descriptors.
  * Improvement of metadata for jack emulation.
  * Fix memory and thread problems in jack emulation.
  * Simplification of state changes. Should make more use
    cases work in the jack emulation.
  * Improvements in the gstreamer elements. Removal of
    extra internal queue. pipewiresink can now be used to
    play audio.
  * Add pw-jack and pw-pulse scripts to run pulseaudio and
    jack applications with the right library path.
- Replace libpulse* replacement packages with a single
  pipewire-libpulse-0_3 package that includes all libraries
  installed in the non-standard directory
  %%{_libdir}/pipewire-0.3/pulse and a new pw-pulse wrapper script.
  Likewise for the jack replacement libraries in a new
  pipewire-libjack-0_3 package.
- Use update-alternatives for the wrapper scripts.
* Wed Apr  1 2020 Antonio Larrosa <alarrosa@suse.com>
- Use the License rpm tag to specify that although most of
  pipewire is licensed under MIT,  the pulseaudio replacement
  library is licensed under LGPL-2.1+.
* Tue Mar 31 2020 Antonio Larrosa <alarrosa@suse.com>
- Use gcc9 to build in SLE-15 / Leap 15, since at least gcc8 is
  needed now.
* Tue Mar 31 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to version 0.3.2:
  + build fixes
  + Added support for data type negotiation. This makes it
    possible for a client to say that it can handle DMABuf
    and MemFd and then let the server select a compatible
    format.
  + Handle errors when enumerating parameters better.
  + Add support for rate, format, channels and period_bytes
    to the alsa config file to restrict what alsa apps can
    negotiate.
  + Fix JACK midi output.
  + Optimizations in common audio format conversions using
    AVX2. Small optimizations to plugins.
  + Change the vulkan compute example to an MIT licensed
    shader.
  + Remove some hardcoded defaults in the audio and video
    processing and use the values from the processing
    context. This also fixes the vulkan example.
  + Correct the documentation and defaults in the daemon
    config file.
  + Fix alsa and v4l2 buffer recycle. A paused client could
    cause the server to leak all buffers.
  + Remove some warnings that should be ignored.
  + Fix a crash in the bluez5 plugins.
  + Try to select higher quality formats first when
    negotiating a format with an audio device.
  + Fix an infinite loop in udev detection in some cases.
  + Add non-interactive mode to pw-cli. You can now just
    do "pw-cli ls Port" to get a listing of all ports.
    pw-cli will now also connect to the default server by
    default and has options to select a different server.
  + Allow the server to go up to the maximum quantum (8192
    samples or ~=180ms) if a client explicitly wants this.
* Mon Mar 23 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.3.1+48:
  + Fix 32bit build.
* Wed Mar 18 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Switch to source service, update to explicit head, file with
  non-compliant license replaced.
* Tue Mar 17 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Switch license to MIT and actually package it.
- Add doxygen, graphviz and xmltoman BuildRequires and pass docs
  and man = true to meson, build documentation. Package docs in a
  new docs sub-package.
- Add check section and run meson_test macro, run tests during
  build.
- Add fdupes BuildRequires and pass fdupes macro, remove duplicate
  files.
* Mon Mar  9 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to version 0.3.1:
  + This is a bugfix release that is API and ABI compatible
    with previous 0.3.x releases.
  + Don't load the rtkit module by default. It can cause a
    sigkill, which is not desirable for mutter, for example.
    Only enable this for the jack library for now.
  + Don't use pthread cancel by default because it uses a
    signal that might crash some apps. Only use it for
    the jack library because jack clients really expect this.
  + Build fixes for -Werror=suggest-attribute=format
  + improve error messages, don't report harmless errors and
    warnings. Try to send error messages to the proxy that
    started the operation or is the owner of the object.
  + pw-cat: midi improvement, add midi recording and dump
    in verbose mode
  + fix properties when loading spa-nodes from the config
  + Fix and update some examples
  + jack: check arguments and don't crash when invalid
  + Fix buffer memory upload.
  + jack: fix compatibility with zrythm. Fix timemaster
    install, improve sample_rate callback. Fix reposition
    handling.
  + fix crash in port after buffer negotiation error.
  + add support for control ports in pw_filter
  + fix cleanup of the metadata module
  + improve param enumeration.
  + Clear stream buffers when the format is cleared.
  + Add create-object command in the config file to create
    object from a factory.
  + Fix crash after the driver was not removed from unassigned
    nodes. Also properly pause inactive nodes.
  + Use "true" and "false" in properties when we are talking
    about a boolean.
  + pulseaudio: improve compatibility
* Fri Feb 21 2020 Antonio Larrosa <alarrosa@suse.com>
- Add patch to build correctly with glibc < 2.27 (like in SLE/Leap):
  * fix-memfd_create-call.patch
* Fri Feb 21 2020 Antonio Larrosa <alarrosa@suse.com>
- Add BuildRequires for pkgconfig(sndfile) and pkgconfig(vulkan)
  so the vulkan plugin is built.
- Version the spa-plugins subpackage so different versions of
  the plugins can be co-installed in the future.
* Thu Feb 20 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.3.0:
  + The 0.3 release is a major milestone in the developement of
    PipeWire. It features a complete redesign of the scheduling
    mechanisms that make it possible to run a JACK compatibility
    layer with comparable performance to JACK2.
  + The API has been reworked and is declared stable now. All
    developement files and runtime paths are versioned so that
    future incompatible changes can be done without breaking
    exising applications.
  + PipeWire 0.3 also includes a (now mandatory) session manager
    that populates and controls the PipeWire graph. This example
    session manager is very simple and not configurable. It is
    expected that future version will either switch to a more
    flexible session manager (like WirePlumber) or improve the
    configuration options of the example session manager.
  + PipeWire 0.3 includes both PulseAudio, JACK and ALSA
    compatibility libraries that are known to support a wide range
    of applications. The ALSA library is pretty complete at this
    point. The JACK and mostly the PulseAudio compatibility
    libraries need more work. See the Wiki pages for the current
    compatibility problems. We do not yet encourage people to
    switch away from their existing audio solutions (PulseAudio
    or JACK) but we would love to hear from people who try it
    anyways. Future versions will mostly focus on improving
    compatibility further to make PipeWire a drop-in replacement.
    PipeWire comes with some GStreamer plugins to consume and
    produce data for PipeWire. The consumer (pipewiresrc) is
    working well in most cases. The sink (pipewiresink) is known
    to be somewhat problematic for now.
- Add pkgconfig(bluez) and pkgconfig(libpulse) BuildRequires: New
  dependencies.
- Bump libpipewire, apiver and spa_ver define following upstreams
  changes. Also add a new sover define.
- Package new subpackages: libjack-pw0_3_0,
  libpulse-mainloop-glib-pw0_3_0, libpulse-pw0_3_0 and
  libpulse-simple-pw0_3_0, as well as handle them in post(un).
- Adjust options passed to meson following upstreams changes.
* Wed Nov  6 2019 Fabian Vogt <fvogt@suse.com>
- Update to version 0.2.7:
  + Add support for alsa-lib 1.1.9 which changed the include path
  + Improve error checking and reporting in the protocol
  + deviceprovider: fix probing without starting
  + add sentinel to some functions
  + compiler fixes for musl
  + Revert object tree permission checks that broke things, this is
    probably not a good idea (and the tree of objects is going to
    be removed later)
* Wed May 22 2019 Markus S <kamikazow@opensuse.org>
- Update to version 0.2.6:
  + Improve error checking for threads.
  + Fix some memory and fd leaks.
  + Fix compilation with C++ compilers and clang.
  + DISABLE_RTKIT should now not try to use dbus at all.
  + Camera Portal fixes:
  - add Camera media.role.
  - Rename module-flatpak to module-portal.
  - Use the portal permissions store for camera checks.
  + Actually use the passed fd in pipewiresrc.
  + Make properties with "pipewire." prefix read-only.
  + Add security label to client object.
  + Enforce link permissions.
  + Permissions of objects are now combined with parent
    permissions.
  + Remove libv4l2 dependency, it is not used.
  + Improve format negotiation in autolink #146.
  + Try to avoid list corruption with event emmission #143.
  + Fix destroy of client-node memory corruption.
  + Various small improvements.
- Remove pkgconfig(libv4l2) BuildRequires: follow upstreams cleanup
  of build dependencies.
- Drop avoid-invalid-conversion-error-with-C++.patch: fixed
  upstream.
* Fri Apr 19 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix use of headers from C++:
  * avoid-invalid-conversion-error-with-C++.patch
* Thu Feb 21 2019 bjorn.lie@gmail.com
- Update to version 0.2.5:
  + Build fixes for systemd.
  + Add cursor and bitmap metadata. This can be used to send a
    cursor sprite with the video stream.
  + Permissions were set too strict for non-flatpak clients.
  + Fix crash in loop caused by thread unsafe hook emission.
  + Add more error checking for thread-loop.
  + Small cleanups and bugfixes.
- Drop libspa define and add spa_ver define, and following this
  drop libspa-lib1 subpackage, no longer built.
- Drop doxygen BuildRequires and manpages source, follow upstream
  in not building docs nor manually installing manpages that have
  to be updated every version bump to ensure they are current.
- Add pkgconfig(libsystemd) BuildRequires: New dependency.
- Update options passed to meson following upstream changes.
* Mon Aug 13 2018 bjorn.lie@gmail.com
- Update to version 0.2.2:
  + Add apiversion to pkgconfig as well.
- Add apiver define and set it to 0.2.
- Bump libpipewire define to libpipewire-0_2-1 and libspa define to
  libspa-lib1 following upstream changes.
* Mon Jul 23 2018 bjorn.lie@gmail.com
- Update to version 0.2.1:
  + stream: update to latest API.
  + hook: add private data for future expansion.
* Tue Jul 17 2018 alarrosa@suse.com
- Update to version 0.2.0
  * No changelog provided by upstream. To see the changes in this
    version, please browse the commit logs at
    https://github.com/PipeWire/pipewire/commits/0.2.0 .
* Tue Mar 13 2018 luc14n0@linuxmail.org
- Initial package, version 0.1.9.
